#[non_exhaustive]pub enum ResultGroupMap {
RoomId(BTreeMap<OwnedRoomId, ResultGroup>),
Sender(BTreeMap<OwnedUserId, ResultGroup>),
}Available on crate features
client or server only.Expand description
A map of results grouped by key.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
RoomId(BTreeMap<OwnedRoomId, ResultGroup>)
Results grouped by room ID.
Sender(BTreeMap<OwnedUserId, ResultGroup>)
Results grouped by sender.
Implementations
Sourceimpl ResultGroupMap
impl ResultGroupMap
Sourcepub fn grouping_key(&self) -> GroupingKey
pub fn grouping_key(&self) -> GroupingKey
The key that was used to group this map.
Sourcepub fn custom_map(&self) -> Option<&BTreeMap<String, ResultGroup>>
pub fn custom_map(&self) -> Option<&BTreeMap<String, ResultGroup>>
The map of grouped results, if this uses a custom key.
Sourcepub fn into_custom_map(self) -> Option<BTreeMap<String, ResultGroup>>
pub fn into_custom_map(self) -> Option<BTreeMap<String, ResultGroup>>
Convert this into the map of grouped results, if this uses a custom key.